@@ -58,7 +58,7 @@ from easybuild.tools.filetools import encode_class_name, extract_file, run_cmd,
 from easybuild.tools.filetools import decode_class_name, write_file
 from easybuild.tools.module_generator import GENERAL_CLASS, ModuleGenerator
 from easybuild.tools.modules import ROOT_ENV_VAR_NAME_PREFIX, VERSION_ENV_VAR_NAME_PREFIX, DEVEL_ENV_VAR_NAME_PREFIX
-from easybuild.tools.modules import Modules, get_software_root
+from easybuild.tools.modules import get_software_root, modules_tool
 from easybuild.tools.systemtools import get_core_count
 from easybuild.tools.utilities import remove_unwanted_chars
 from easybuild.tools.version import this_is_easybuild, VERBOSE_VERSION, VERSION
@@ -105,18 +105,21 @@ class EasyBlock(object):
         self.skip = None
         self.module_extra_extensions = ''  # extra stuff for module file required by extensions
 
-        # easyconfig for this application
-        all_stops = [x[0] for x in self.get_steps()]
-        self.cfg = EasyConfig(path,
-                              extra_options=self.extra_options(),
-                              validate=validate_ec,
-                              valid_module_classes=module_classes(),
-                              valid_stops=all_stops
-                              )
-
+        # modules interface with default MODULEPATH
+        self.modules_tool = modules_tool()
         # module generator
         self.moduleGenerator = None
 
+        # easyconfig for this application
+        all_stops = [x[0] for x in self.get_steps()]
+        self.cfg = EasyConfig(
+            path,
+            extra_options=self.extra_options(),
+            validate=validate_ec,
+            valid_module_classes=module_classes(),
+            valid_stops=all_stops,
+        )
+
         # indicates whether build should be performed in installation dir
         self.build_in_installdir = False
 
@@ -155,7 +158,7 @@ class EasyBlock(object):
         if not self.log is None:
             return
 
-        self.logfile = get_log_filename(self.name, self.version)
+        self.logfile = get_log_filename(self.name, self.version, add_salt=True)
         fancylogger.logToFile(self.logfile)
 
         self.log = fancylogger.getLogger(name=self.__class__.__name__, fname=False)
@@ -776,7 +779,7 @@ class EasyBlock(object):
         """
         Load module for this software package/version, after purging all currently loaded modules.
         """
-        m = Modules(mod_paths)
+        m = modules_tool(mod_paths)
         # purge all loaded modules if desired
         if purge:
             m.purge()
@@ -792,10 +795,10 @@ class EasyBlock(object):
         # take a copy of the environment before loading the fake module, so we can restore it
         orig_env = copy.deepcopy(os.environ)
 
-        # make fake module
+        # create fake module
         fake_mod_path = self.make_module_step(True)
 
-        # create Modules instance
+        # load fake module
         mod_paths = [fake_mod_path]
         mod_paths.extend(self.orig_modulepath.split(':'))
         self.log.debug("mod_paths: %s" % mod_paths)
@@ -815,8 +818,8 @@ class EasyBlock(object):
         if fake_mod_path:
             try:
                 mod_paths = [fake_mod_path]
-                mod_paths.extend(Modules().modulePath)
-                m = Modules(mod_paths)
+                mod_paths.extend(self.modules_tool.mod_paths)
+                m = modules_tool(mod_paths)
                 m.add_module([[self.name, self.get_installversion()]])
                 m.unload()
                 rmtree2(os.path.dirname(fake_mod_path))
@@ -978,7 +981,7 @@ class EasyBlock(object):
         Prints the environment changes and loaded modules to the debug log
         - pretty prints the environment for easy copy-pasting
         """
-        mods = [(mod['name'], mod['version']) for mod in Modules().loaded_modules()]
+        mods = [(mod['name'], mod['version']) for mod in self.modules_tool.loaded_modules()]
         mods_text = "\n".join(["module load %s/%s" % m for m in mods if m not in self.loaded_modules])
         self.loaded_modules = mods
 
@@ -1074,7 +1077,7 @@ class EasyBlock(object):
         Verify if all is ok to start build.
         """
         # Check whether modules are loaded
-        loadedmods = Modules().loaded_modules()
+        loadedmods = self.modules_tool.loaded_modules()
         if len(loadedmods) > 0:
             self.log.warning("Loaded modules detected: %s" % loadedmods)
 
@@ -1094,7 +1097,7 @@ class EasyBlock(object):
         # - if a current module can be found, skip is ok
         # -- this is potentially very dangerous
         if self.cfg['skip']:
-            if Modules().exists(self.name, self.get_installversion()):
+            if self.modules_tool.exists(self.name, self.get_installversion()):
                 self.skip = True
                 self.log.info("Current version (name: %s, version: %s) found." % (self.name, self.get_installversion))
                 self.log.info("Going to skip actually main build and potential existing extensions. Expert only.")
@@ -1349,14 +1352,12 @@ class EasyBlock(object):
             else:
                 try:
                     cls = get_class_for(default_class_modpath, default_class)
+                    self.log.debug("Obtained class %s for installing extension %s" % (cls, ext['name']))
                     inst = cls(self, ext)
                     self.log.debug("Installing extension %s with default class %s" % (ext['name'], default_class))
-                except (ImportError, NameError), errbis:
-                    msg = "Also failed to use default class %s from %s for extension %s: %s" % (default_class,
-                                                                                                default_class_modpath,
-                                                                                                ext['name'],
-                                                                                                err)
-                    msg += ", giving up:\n%s\n%s" % (err, errbis)
+                except (ImportError, NameError), err:
+                    msg = "Also failed to use default class %s from %s for extension %s: %s, giving up" % \
+                        (default_class, default_class_modpath, ext['name'], err)
                     self.log.error(msg)
 
             # real work
@@ -1569,6 +1570,8 @@ class EasyBlock(object):
         if not fake:
             self.make_devel_module()
 
+        self.modules_tool.update()
+
         return modpath
 
     def test_cases_step(self):
