@@ -33,6 +33,7 @@ alongside the EasyConfig class to represent parsed easyconfig files.
 @author: Pieter De Baets (Ghent University)
 @author: Jens Timmerman (Ghent University)
 @author: Toon Willems (Ghent University)
+@author: Fotis Georgatos (University of Luxembourg)
 """
 
 import copy
@@ -343,6 +344,10 @@ def select_or_generate_ec(fp, paths, specs):
         elif val:
             # if a value is specified, use that, even if it's not available yet
             selected_val = val
+            # promote value to list if deemed appropriate
+            if vals and type(vals[0]) == list and not type(val) == list:
+                _log.debug("Promoting type of %s value to list, since original value was." % param)
+                specs[param] = [val]
             _log.debug("%s is specified, so using it (even though it's not available yet): %s" % (param, selected_val))
         elif len(vals) == 1:
             # if only one value is available, use that
@@ -462,7 +467,20 @@ def tweak(src_fn, target_fn, tweaks):
 
             res = regexp.search(ectxt)
             if res:
-                newval = "%s + %s" % (val, res.group(1))
+                fval = [x for x in val if x != '']  # filter out empty strings
+                # determine to prepend/append or overwrite by checking first/last list item
+                # - input ending with comma (empty tail list element) => prepend
+                # - input starting with comma (empty head list element) => append
+                # - no empty head/tail list element => overwrite
+                if val[0] == '':
+                    newval = "%s + %s" % (res.group(1), fval)
+                    _log.debug("Appending %s to %s" % (fval, key))
+                elif val[-1] == '':
+                    newval = "%s + %s" % (fval, res.group(1))
+                    _log.debug("Prepending %s to %s" % (fval, key))
+                else:
+                    newval = "%s" % fval
+                    _log.debug("Overwriting %s with %s" % (key, fval))
                 ectxt = regexp.sub("%s = %s # tweaked by EasyBuild (was: %s)" % (key, newval, res.group(1)), ectxt)
                 _log.info("Tweaked %s list to '%s'" % (key, newval))
             else:
