@@ -34,12 +34,14 @@ EasyBuild configuration (paths, preferences, etc.)
 """
 
 import os
+import random
+import string
 import tempfile
 import time
 from vsc import fancylogger
 from vsc.utils.missing import nub
 
-from easybuild.tools.repository import Repository, get_repositories
+import easybuild.tools.build_log  # this import is required to obtain a correct (EasyBuild) logger!
 from easybuild.tools.utilities import read_environment as _read_environment
 
 
@@ -249,6 +251,7 @@ def get_default_oldstyle_configfile_defaults(prefix=None):
         'moduleclasses': [x[0] for x in DEFAULT_MODULECLASSES],
         'subdir_modules': DEFAULT_PATH_SUBDIRS['subdir_modules'],
         'subdir_software': DEFAULT_PATH_SUBDIRS['subdir_software'],
+        'modules_tool': 'EnvironmentModulesC',
     }
 
     # sanity check
@@ -302,19 +305,6 @@ def init(options, config_options_dict):
 
     _log.debug("Config variables: %s" % variables)
 
-    # Create an instance of the repository class
-    if 'repository' in variables and not isinstance(variables['repository'], Repository):
-        repo = get_repositories().get(options.repository)
-        repoargs = options.repositorypath
-
-        try:
-            repository = repo(*repoargs)
-        except Exception, err:
-            _log.error('Failed to create a repository instance for %s (class %s) with args %s (msg: %s)' %
-                       (options.repository, repo.__name__, repoargs, err))
-
-        variables['repository'] = repository
-
     def create_dir(dirtype, dirname):
         _log.debug('Will try to create the %s directory %s.' % (dirtype, dirname))
         try:
@@ -391,6 +381,20 @@ def get_repository():
     return variables['repository']
 
 
+def get_repositorypath():
+    """
+    Return the repository path
+    """
+    return variables['repositorypath']
+
+
+def get_modules_tool():
+    """
+    Return modules tool (EnvironmentModulesC, Lmod, ...)
+    """
+    return variables['modules_tool']
+
+
 def log_file_format(return_directory=False):
     """Return the format for the logfile or the directory"""
     idx = int(not return_directory)
@@ -433,27 +437,34 @@ def get_build_log_path():
         return defaults['tmp_logdir']
 
 
-def get_log_filename(name, version):
+def get_log_filename(name, version, add_salt=False):
     """
     Generate a filename to be used for logging
     """
     date = time.strftime("%Y%m%d")
     timeStamp = time.strftime("%H%M%S")
 
-    filename = os.path.join(get_build_log_path(), log_file_format() % {
-                                                                       'name': name,
-                                                                       'version': version,
-                                                                       'date': date,
-                                                                       'time': timeStamp
-                                                                       })
+    filename = log_file_format() % {
+        'name': name,
+        'version': version,
+        'date': date,
+        'time': timeStamp,
+    }
+
+    if add_salt:
+        salt = ''.join(random.choice(string.letters) for i in range(5))
+        filename_parts = filename.split('.')
+        filename = '.'.join(filename_parts[:-1] + [salt, filename_parts[-1]])
+
+    filepath = os.path.join(get_build_log_path(), filename)
 
     # Append numbers if the log file already exist
     counter = 1
-    while os.path.isfile(filename):
+    while os.path.isfile(filepath):
         counter += 1
-        filename = "%s.%d" % (filename, counter)
+        filepath = "%s.%d" % (filepath, counter)
 
-    return filename
+    return filepath
 
 
 def read_only_installdir():
@@ -508,7 +519,10 @@ def oldstyle_read_configuration(filename):
     """
     _log.deprecated("oldstyle_read_configuration filename %s" % filename, "2.0")
 
-    file_variables = get_repositories(check_usable=False)
+    # import avail_repositories here to avoid cyclic dependencies
+    # this block of code is going to be removed in EB v2.0
+    from easybuild.tools.repository import avail_repositories
+    file_variables = avail_repositories(check_useable=False)
     try:
         execfile(filename, {}, file_variables)
     except (IOError, SyntaxError), err:
