@@ -36,6 +36,7 @@ import shutil
 import tempfile
 from vsc import fancylogger
 
+import easybuild.tools.options as eboptions
 import easybuild.framework.easyconfig as easyconfig
 from unittest import TestCase, TestLoader, main
 from easybuild.framework.easyblock import EasyBlock
@@ -52,6 +53,11 @@ class EasyConfigTest(TestCase):
     contents = None
     eb_file = ''
 
+    # initialize configuration so config.get_modules_tool function works
+    eb_go = eboptions.parse_options()
+    config.init(eb_go.options, eb_go.get_options_by_section('config'))
+    del eb_go
+
     def setUp(self):
         """ create temporary easyconfig file """
         self.log = fancylogger.getLogger("EasyConfigTest", fname=False)
@@ -77,10 +83,10 @@ class EasyConfigTest(TestCase):
             os.remove(self.eb_file)
         os.chdir(self.cwd)
 
-    def assertErrorRegex(self, error, regex, call, *args):
+    def assertErrorRegex(self, error, regex, call, *args, **kwargs):
         """ convenience method to match regex with the error message """
         try:
-            call(*args)
+            call(*args, **kwargs)
             self.assertTrue(False)  # this will fail when no exception is thrown at all
         except error, err:
             res = re.search(regex, err.msg)
@@ -327,7 +333,7 @@ class EasyConfigTest(TestCase):
         versuff = "mysuffix"
         tcname = "mytc"
         tcver = "4.1.2"
-        extra_patches = ['t5.patch', 't6.patch']
+        new_patches = ['t5.patch', 't6.patch']
         homepage = "http://www.justatest.com"
 
         tweaks = {
@@ -335,7 +341,7 @@ class EasyConfigTest(TestCase):
                   'versionprefix': verpref,
                   'versionsuffix': versuff,
                   'toolchain_version': tcver,
-                  'patches': extra_patches
+                  'patches': new_patches
                  }
         tweak(self.eb_file, tweaked_fn, tweaks)
 
@@ -344,7 +350,7 @@ class EasyConfigTest(TestCase):
         self.assertEqual(eb['versionprefix'], verpref)
         self.assertEqual(eb['versionsuffix'], versuff)
         self.assertEqual(eb['toolchain']['version'], tcver)
-        self.assertEqual(eb['patches'], extra_patches + patches)
+        self.assertEqual(eb['patches'], new_patches)
 
         eb = EasyConfig(self.eb_file, valid_stops=self.all_stops)
         # eb['toolchain']['version'] = tcver does not work as expected with templating enabled
@@ -355,21 +361,26 @@ class EasyConfigTest(TestCase):
         eb.dump(self.eb_file)
 
         tweaks = {
-                  'toolchain_name': tcname,
-                  'patches': extra_patches[0:1],
-                  'homepage': homepage,
-                  'foo': "bar"
-                 }
+            'toolchain_name': tcname,
+            'patches': new_patches[:1],
+            'homepage': homepage,
+            'foo': "bar"
+        }
 
         tweak(self.eb_file, tweaked_fn, tweaks)
 
         eb = EasyConfig(tweaked_fn, valid_stops=self.all_stops)
         self.assertEqual(eb['toolchain']['name'], tcname)
         self.assertEqual(eb['toolchain']['version'], tcver)
-        self.assertEqual(eb['patches'], extra_patches[0:1] + patches)
+        self.assertEqual(eb['patches'], new_patches[:1])
         self.assertEqual(eb['version'], ver)
         self.assertEqual(eb['homepage'], homepage)
 
+        # specify patches as string, eb should promote it to a list because original value was a list
+        tweaks['patches'] = new_patches[0]
+        eb = EasyConfig(tweaked_fn, valid_stops=self.all_stops)
+        self.assertEqual(eb['patches'], [new_patches[0]])
+
         # cleanup
         os.remove(tweaked_fn)
 
@@ -517,19 +528,36 @@ class EasyConfigTest(TestCase):
 
 
         # should be able to prepend to list of patches and handle list of dependencies
-        extra_patches = ['two.patch', 'three.patch']
+        new_patches = ['two.patch', 'three.patch']
         deps = [('foo', '1.2.3'), ('bar', '666')]
         specs.update({
-                      'patches': extra_patches,
+                      'patches': new_patches[:],
                       'dependencies': deps
                      })
         res = obtain_ec_for(specs, [self.ec_dir], None)
         self.assertEqual(res[0], True)
         ec = EasyConfig(res[1], valid_stops=self.all_stops)
-        self.assertEqual(ec['patches'], specs['patches'] + patches)
+        self.assertEqual(ec['patches'], specs['patches'])
         self.assertEqual(ec['dependencies'], specs['dependencies'])
         os.remove(res[1])
 
+        # verify append functionality for lists
+        specs['patches'].insert(0, '')
+        res = obtain_ec_for(specs, [self.ec_dir], None)
+        self.assertEqual(res[0], True)
+        ec = EasyConfig(res[1], valid_stops=self.all_stops)
+        self.assertEqual(ec['patches'], patches + new_patches)
+        specs['patches'].remove('')
+        os.remove(res[1])
+
+        # verify prepend functionality for lists
+        specs['patches'].append('')
+        res = obtain_ec_for(specs, [self.ec_dir], None)
+        self.assertEqual(res[0], True)
+        ec = EasyConfig(res[1], valid_stops=self.all_stops)
+        self.assertEqual(ec['patches'], new_patches + patches)
+        os.remove(res[1])
+
         # should use supplied filename
         fn = "my.eb"
         res = obtain_ec_for(specs, [self.ec_dir], fn)
