@@ -33,20 +33,27 @@ Unit tests for modules.py.
 import os
 import re
 
-import easybuild.tools.modules as modules
+import easybuild.tools.options as eboptions
+from easybuild.tools import config
+from easybuild.tools.modules import modules_tool
 from unittest import TestCase, TestLoader, main
 
 
 class ModulesTest(TestCase):
     """ small test for Modules """
 
+    # initialize configuration so modules_tool function works
+    eb_go = eboptions.parse_options()
+    config.init(eb_go.options, eb_go.get_options_by_section('config'))
+    del eb_go
+
     def setUp(self):
         """setup"""
         self.cwd = os.getcwd()
 
     def test_load(self):
         """ test if we load one module it is in the loaded_modules """
-        testmods = modules.Modules([os.path.join(os.path.dirname(__file__), 'modules')])
+        testmods = modules_tool([os.path.join(os.path.dirname(__file__), 'modules')])
         ms = testmods.available('', None)
         for m in ms:
             testmods.add_module([m])
@@ -66,7 +73,7 @@ class ModulesTest(TestCase):
 
         os.environ['LD_LIBRARY_PATH'] = testpath
 
-        testmods = modules.Modules([os.path.join(os.path.dirname(__file__), 'modules')])
+        testmods = modules_tool([os.path.join(os.path.dirname(__file__), 'modules')])
         testmods.add_module([('GCC', '4.6.3')])
         testmods.load()
 
@@ -75,7 +82,7 @@ class ModulesTest(TestCase):
 
     def test_purge(self):
         """Test if purging of modules works."""
-        m = modules.Modules([os.path.join(os.path.dirname(__file__), 'modules')])
+        m = modules_tool([os.path.join(os.path.dirname(__file__), 'modules')])
 
         ms = m.available('', None)
         m.add_module([ms[0]])
